BackwardNavigableGraph

Trait BackwardNavigableGraph 

pub trait BackwardNavigableGraph<'a, N, E>: Graph<N, E> {
    type InEdgeIterator: Iterator<Item = EdgeId> + 'a;

    // Required method
    fn in_edges(&self, id: NodeId) -> Self::InEdgeIterator;
}
A backward navigable graph.

Graphs implementing this trait are able to output a nodes in-edges efficiently. For undirected graphs, out-edges and in-edges are the same.

Required Associated Types

type InEdgeIterator: Iterator<Item = EdgeId> + 'a

An iterator over the in-edges of a node.

Required Methods

fn in_edges(&self, id: NodeId) -> Self::InEdgeIterator

Returns an iterator over the in-edges of the node identified by the given id.

Implementors